render_region_prepared

Function render_region_prepared 

pub fn render_region_prepared(
    list: &DisplayList,
    prepared: &PreparedDisplayList,
    vp_x: f64,
    vp_y: f64,
    vp_w: f64,
    vp_h: f64,
    pixel_w: u32,
    pixel_h: u32,
    dpi: f64,
    icc: Option<&IccCache>,
    image_cache: Option<&ImageCache>,
    no_aa: bool,
) -> Vec<u8> 
Render a rectangular viewport region using precomputed metadata.

Like render_region() but skips the three precomputation passes, using the PreparedDisplayList instead. Significantly faster for repeated renders of the same display list (e.g., panning at a fixed zoom).