pub fn render_region_prepared_parallel_with_progress(
list: &DisplayList,
prepared: &PreparedDisplayList,
vp_x: f64,
vp_y: f64,
vp_w: f64,
vp_h: f64,
pixel_w: u32,
pixel_h: u32,
dpi: f64,
icc: Option<&IccCache>,
image_cache: Option<&ImageCache>,
no_aa: bool,
progress: &AtomicU32,
) -> Vec<u8> ⓘExpand description
Like render_region_prepared_parallel() but with an atomic progress counter.
The counter is incremented after each chunk of bands completes. The total
number of bands is returned alongside the counter via viewport_band_count().